Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(63)

Unified Diff: content/public/browser/security_style_explanations.h

Issue 2118583003: Display when PKP is bypassed in devtools (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Add comments Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/security_style_explanations.h
diff --git a/content/public/browser/security_style_explanations.h b/content/public/browser/security_style_explanations.h
index adba598e70265dc17b3a768549cd346260948af6..3b8a28d53cab0b6c08f160fe374c1a8f98aab7a8 100644
--- a/content/public/browser/security_style_explanations.h
+++ b/content/public/browser/security_style_explanations.h
@@ -23,7 +23,7 @@ namespace content {
// SecurityStyleExplanation is a single security property of a page (for
// example, an expired certificate, a valid certificate, or the presence
// of a deprecated crypto algorithm). A single site may have multiple
// different explanations of "secure", "warning", and "broken" severity
// levels.
struct SecurityStyleExplanations {
CONTENT_EXPORT SecurityStyleExplanations();
@@ -49,9 +49,12 @@ struct SecurityStyleExplanations {
// True if PKP was bypassed due to a local trust anchor.
bool pkp_bypassed;
+ // Explanations corresponding to each security level. The embedder should
+ // display explanations in the order: broken, unauthenticated, secure, info.
std::vector<SecurityStyleExplanation> secure_explanations;
std::vector<SecurityStyleExplanation> unauthenticated_explanations;
std::vector<SecurityStyleExplanation> broken_explanations;
+ std::vector<SecurityStyleExplanation> info_explanations;
};
} // namespace content
@@ -23,7 +23,7 @@ namespace content {
// example, an expired certificate, a valid certificate, or the presence
// of a deprecated crypto algorithm). A single site may have multiple
-// different explanations of "secure", "warning", and "broken" severity
+// different explanations of "secure", "warning", "broken", and "info" severity
// levels.
struct SecurityStyleExplanations {

Powered by Google App Engine
This is Rietveld 408576698